******
finder
******

|version| |travis| |coveralls| |license|

Command line interface for searching a given pattern in the given directory/file paths.

Links
=====

 - Project: https://github.com/bharadwajyarlagadda/finder
 - Documentation: Wiki_
 - Pypi: https://pypi.python.org/pypi/finder
 - TravisCI: https://travis-ci.org/bharadwajyarlagadda/finder

Quickstart
==========

Install using pip:

::

    pip install finder


Features
========

- Supported on Python 3.3+.


.. |version| image:: https://img.shields.io/pypi/v/finder.svg?style=flat-square
    :target: https://pypi.python.org/pypi/finder/

.. |travis| image:: https://img.shields.io/travis/bharadwajyarlagadda/finder/master.svg?style=flat-square
    :target: https://travis-ci.org/bharadwajyarlagadda/finder

.. |coveralls| image:: https://img.shields.io/coveralls/bharadwajyarlagadda/finder/master.svg?style=flat-square
    :target: https://coveralls.io/r/bharadwajyarlagadda/finder

.. |license| image:: https://img.shields.io/pypi/l/finder.svg?style=flat-square
    :target: https://github.com/bharadwajyarlagadda/finder/blob/master/LICENSE.rst


.. _Wiki: https://github.com/bharadwajyarlagadda/finder/wiki